==> vala-0.3.2.tar.gz: vala-0.3.2/ccode/valaccodeexpression.c <==
/* valaccodeexpression.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodeexpression.h>




enum  {
	VALA_CCODE_EXPRESSION_DUMMY_PROPERTY
};
static gpointer vala_ccode_expression_parent_class = NULL;



/**
 * Represents an expression node in the C code tree.
 */
ValaCCodeExpression* vala_ccode_expression_new (void) {
	ValaCCodeExpression * self;
	self = g_object_newv (VALA_TYPE_CCODE_EXPRESSION, 0, NULL);
	return self;
}


static void vala_ccode_expression_class_init (ValaCCodeExpressionClass * klass) {
	vala_ccode_expression_parent_class = g_type_class_peek_parent (klass);
}


static void vala_ccode_expression_init (ValaCCodeExpression * self) {
}


GType vala_ccode_expression_get_type (void) {
	static GType vala_ccode_expression_type_id = 0;
	if (G_UNLIKELY (vala_ccode_expression_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpression), 0, (GInstanceInitFunc) vala_ccode_expression_init };
		vala_ccode_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeExpression", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	}
	return vala_ccode_expression_type_id;
}

==> vala-0.3.5.tar.gz: vala-0.3.5/ccode/valaccodeexpression.c <==
/* valaccodeexpression.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodeexpression.h>




enum  {
	VALA_CCODE_EXPRESSION_DUMMY_PROPERTY
};
static gpointer vala_ccode_expression_parent_class = NULL;



static void vala_ccode_expression_class_init (ValaCCodeExpressionClass * klass) {
	vala_ccode_expression_parent_class = g_type_class_peek_parent (klass);
}


static void vala_ccode_expression_instance_init (ValaCCodeExpression * self) {
}


GType vala_ccode_expression_get_type (void) {
	static GType vala_ccode_expression_type_id = 0;
	if (vala_ccode_expression_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpression), 0, (GInstanceInitFunc) vala_ccode_expression_instance_init };
		vala_ccode_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeExpression", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	}
	return vala_ccode_expression_type_id;
}
